==> haskell-executable-path-0.0.3.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-executable-path.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: executable-path
version: 0.0.3.1
id: executable-path-0.0.3.1-HAUXy7yynGAqn9mH431ik
key: executable-path-0.0.3.1-HAUXy7yynGAqn9mH431ik
license: LicenseRef-PublicDomain
maintainer: bkomuves (plus) hackage (at) gmail (dot) com
author: Balazs Komuves
stability: Experimental
homepage: http://code.haskell.org/~bkomuves/
synopsis: Finding out the full path of the executable.
description:
    The documentation of "System.Environment.getProgName" says that
    \"However, this is hard-to-impossible to implement on some non-Unix OSes,
    so instead, for maximum portability, we just return the leafname
    of the program as invoked.\"
    This library tries to provide the missing path.
    Note: Since base 4.6.0.0, there is also a function
    "System.Environment.getExecutablePath".
category: System
abi: 859719b3b8ca55b5026aafab5385e07f
exposed: True
exposed-modules:
    System.Environment.Executable
hidden-modules: System.Environment.Executable.Linux
import-dirs: /usr/lib/ghc-8.4.3/site-local/executable-path-0.0.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/executable-path-0.0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/executable-path-0.0.3.1
hs-libraries: HSexecutable-path-0.0.3.1-HAUXy7yynGAqn9mH431ik
depends:
    base-4.11.1.0 directory-1.3.1.5 filepath-1.4.2 unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-executable-path/html/executable-path.haddock
haddock-html: /usr/share/doc/haskell-executable-path/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-executable-path-0.0.3.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-executable-path.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: executable-path
version: 0.0.3.1
id: executable-path-0.0.3.1-9dmdEZR5Jfi4V3umpMCB9u
key: executable-path-0.0.3.1-9dmdEZR5Jfi4V3umpMCB9u
license: LicenseRef-PublicDomain
maintainer: bkomuves (plus) hackage (at) gmail (dot) com
author: Balazs Komuves
stability: Experimental
homepage: http://code.haskell.org/~bkomuves/
synopsis: Finding out the full path of the executable.
description:
    The documentation of "System.Environment.getProgName" says that
    \"However, this is hard-to-impossible to implement on some non-Unix OSes,
    so instead, for maximum portability, we just return the leafname
    of the program as invoked.\"
    This library tries to provide the missing path.
    Note: Since base 4.6.0.0, there is also a function
    "System.Environment.getExecutablePath".
category: System
abi: b2c21d9fb428ae7226b6e6ef530fab38
exposed: True
exposed-modules:
    System.Environment.Executable
hidden-modules: System.Environment.Executable.Linux
import-dirs: /usr/lib/ghc-8.6.1/site-local/executable-path-0.0.3.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/executable-path-0.0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/executable-path-0.0.3.1
hs-libraries: HSexecutable-path-0.0.3.1-9dmdEZR5Jfi4V3umpMCB9u
depends:
    base-4.12.0.0 directory-1.3.3.0 filepath-1.4.2.1 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-executable-path/html/executable-path.haddock
haddock-html: /usr/share/doc/haskell-executable-path/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
